Minnesota Court of Appeals Published Opinions

Minnesota Court of Appeals
April - June 2014
Published Opinions

#### June 30, 2014

- A13-1689, State of Minnesota, Appellant, vs. Stacie Ann Miller, Respondent.
- A13-2177, Yolanda Bass, Respondent, vs. Equity Residential Holdings, LLC, Appellant.

#### June 23, 2014

- NO PUBLISHED OPINIONS FILED

  #### June 16, 2014

- A13-745,A13-1198, In the Matter of Whether There is a Need for an Environmental Impact Statement (EIS) Regarding the David Nisbit Quarry Conditional Use Permit Application to Extract Industrial Sand, Pauline Connaughty, et al., Relators, vs. Winona County Board of Commissioners, Respondent, David Nisbit, Respondent, Sherry Nisbit, Respondent, Tom Rowekamp, Respondent.
- A13-1772, State of Minnesota, Appellant, vs. Carl Lee Nodes, Respondent.

#### June 9, 2014

- A13-2112, Minnesota Joint Underwriting Association, Appellant, vs. Star Tribune Media Company, LLC, Respondent.
- A14-0095, Hollis John Larson, Appellant, vs. Lucinda Jesson, Commissioner of Human Services, Respondent.

#### June 2, 2014

- A13-1095, In re the Marriage of: Melissa Lynn Gossman, petitioner, Respondent, vs. Jonathan Douglas Gossman, Appellant.
- A13-1566, SN4, LLC, et al., Appellants, vs. Anchor Bank, fsb, Respondent, 22801 7th, LLC, Respondent.
- A13-1956, Charles Patrick Maiers, petitioner, Appellant, vs. Tom Roy, Commissioner of Corrections, Respondent.

#### May 27, 2014

- A13-256, State of Minnesota, Respondent, vs. Paul Joseph Welle, Appellant.
- A13-1129, State of Minnesota, Respondent, vs. Michael David Franklin, Appellant.
- A13-1346, State of Minnesota, Respondent, vs. Jeffrey Micheal Thiel, Appellant.
- A13-1348, In the Matter of the Guardianship of: Michael Timothy O�Brien, Ward.
- A13-1571, State of Minnesota, Respondent, vs. David Loren Haukos, Appellant.

#### May 19, 2014

- A13-401, State of Minnesota, Respondent, vs. Pedro Ayala-Leyva, Appellant.
- A13-1175, State of Minnesota, Respondent, vs. Andrea Lee St. John, Appellant.
- A13-1461, In the Matter of Reichmann Land and Cattle, LLP.

#### May 12, 2014

- A13-400, State of Minnesota, Respondent, vs. Melvin Antwon Griffin, Appellant.
- A13-707, John Kalenburg, et al., Appellants, vs. Thomas H. Klein, et al., Respondents.

#### May 5, 2014

- NO PUBLISHED OPINIONS FILED

  #### April 28, 2014

- A13-1287, Aireal Icenhower, Relator, vs. Total Automotive, Inc., Respondent, Department of Employment and Economic Development, Respondent.

#### April 21, 2014

- A13-1072, Yvette Ford, Appellant, vs. Minneapolis Public Schools, Respondent.
- A13-1302, Robert Meeker, et al., Appellants, vs. IDS Property Casualty Insurance Company, Respondent.
- A13-1448, Douglas W. Butler, et al., Respondents, vs. JLA Industrial Equipment, Inc. d/b/a Hotsy Equipment of Minnesota, Respondent, Schieffer Co. International, LC, Respondent, Alfred Karcher, Inc. d/b/a Karcher North America, et al., Defendants, Magam Enterprises Group, Appellant.
- A13-1520, Abshir Abtidon Barrow, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-2025, In the Matter of the Welfare of the Children of: B. M., J. M. and C. G., Parents.

#### April 14, 2014

- A13-1041, State of Minnesota, Respondent, vs. Kevin Ervin Stall, Appellant.
- A13-1433, State of Minnesota, Appellant, vs. Gregory Eugene Ward, Respondent.
- A13-1628, In the Matter of the Estate of: Janet Rae Pawlik, a/k/a Janet R. Pawlik, a/k/a Janet Pawlik, Deceased.

#### April 7, 2014

- A12-263, State of Minnesota, Respondent, vs. Christopher Thomas Wenthe, Appellant.
- A13-416, State of Minnesota, Respondent, vs. Derek Allen Carlson, Appellant.
- A13-1048, State of Minnesota, Respondent, vs. Nadezhda Vytchesdavvvna Wood, Appellant.
- A13-1189, State of Minnesota, Appellant, vs. Brandon Wayne Riggs, Respondent.
- A13-1524, Keith Eugene Washington, a/k/a Monroe Bernard Washington petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1525, Cristina Eley, Relator, vs. Southshore Investments, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1477, Rochester City Lines, Co., Appellant, vs. City of Rochester, et al., Respondents, First Transit, Inc., Respondent, and Daniel Holter, third party plaintiff, Appellant, vs. Michael Wojcik, third party defendant, Respondent.

MSLL Home Page | | Minnesota Appellate Court System | | Archive Homepage

Phone: (651) 296-2775; Fax: (651) 296-6740

This site is continually being updated and we welcome your input.
Please send any comments or suggestions to the Webweaver.

Last update: June 30, 2014